@@ -2,7 +2,7 @@ from unittest import TestCase
 from mock import patch, MagicMock
 
 from jamd import jamd_viewer
-import markdown_parser
+from jamd import markdown_parser
 
 
 class TestJamdViewer(TestCase):
